@@ -9,11 +9,17 @@ from django.core.exceptions import ValidationError
 from django.db import models
 from django.db.models.query import QuerySet
 
-# just using this to parse, but totally insane package naming...
-# https://bitbucket.org/schinckel/django-timedelta-field/
+from drip.campaigns.models import Campaign
 from drip.helpers import parse
 from drip.types import BoolOrStr, FExpressionOrStr, FieldValue, TimeDeltaOrStr
-from drip.utils import get_user_model
+from drip.utils import get_user_model, validate_schedules
+
+# Raise exception if SCHEDULER is not valid
+validate_schedules()
+
+# from drip.helpers import parse.
+# just using this to parse, but totally insane package naming...
+# https://bitbucket.org/schinckel/django-timedelta-field/
 
 
 class AbstractDrip(models.Model):
@@ -43,7 +49,7 @@ class AbstractDrip(models.Model):
     message_class = models.CharField(max_length=120, blank=True, default="default")
 
     campaign = models.ForeignKey(
-        "campaigns.Campaign",
+        Campaign,
         null=True,
         blank=True,
         default=None,
